@@ -1,6 +1,6 @@
 package Bundle::Everything;
 
-$VERSION = '0.02'
+$VERSION = '0.03'
 
 1;
 
@@ -19,22 +19,32 @@ This probably won't actually work, but it's cool anyway.
 =head1 CONTENTS
 AFS
 
+AFS::Command
+
 AI::Categorize
 
+AI::ExpertSystem::Simple
+
 AI::Fuzzy
 
 AI::Gene::Sequence
 
 AI::Gene::Simple
 
+AI::NNFlex
+
 AI::NeuralNet
 
 AI::NeuralNet::Kohonen
 
 AI::NeuralNet::SOM
 
+AI::Pathfinding::AStar
+
 AI::jNeural
 
+AIX::ODM
+
 ARS
 
 ASP
@@ -45,34 +55,72 @@ Acme::Buffy
 
 Acme::Chef
 
+Acme::Floral
+
 Acme::Morse::Audible
 
 Acme::Playmate
 
+Acme::Pythonic
+
+Acme::Tpyo
+
+Acme::Umlautify
+
+Acme::Wabby
+
+Alarm::Concurrent
+
+Algorithm::BinPack
+
 Algorithm::Cluster
 
 Algorithm::Diff
 
 Algorithm::Graphs::TransitiveClosure
 
+Algorithm::Hamming::Perl
+
+Algorithm::Knapsack
+
 Algorithm::LUHN
 
+Algorithm::Line::Bresenham
+
 Algorithm::Merge
 
+Algorithm::Munkre
+
+Algorithm::Munkres
+
+Algorithm::Networksort
+
 Algorithm::Numerical::Sample
 
 Algorithm::Numerical::Shuffle
 
+Algorithm::Pair::Best
+
 Algorithm::Permute
 
 Algorithm::SISort
 
+Algorithm::ScheduledPath
+
+Algorithm::SixDegrees
+
+Algorithm::SkipList
+
 Alias
 
+Alien
+
 AltaVista::PerlSDK
 
 Alzabo
 
+AnyData
+
 Apache
 
 Apache::ACEProxy
@@ -95,6 +143,8 @@ Apache::Archive
 
 Apache::AuthAny
 
+Apache::AuthCAS
+
 Apache::AuthChecker
 
 Apache::AuthCookie
@@ -109,6 +159,8 @@ Apache::AuthNISPlus
 
 Apache::AuthPerLDAP
 
+Apache::Authen::Program
+
 Apache::AuthenCache
 
 Apache::AuthenDBI
@@ -139,8 +191,12 @@ Apache::AuthzPasswd
 
 Apache::AuthzSSL
 
+Apache::AuthzSplitDomainUser
+
 Apache::AutoIndex
 
+Apache::AutoLogin
+
 Apache::AxKit
 
 Apache::Backhand
@@ -219,12 +275,12 @@ Apache::Htaccess
 
 Apache::Icon
 
+Apache::Language
+
 Apache::Layer
 
 Apache::Leak
 
-Apache::Lint
-
 Apache::Log::Spread
 
 Apache::LogFile
@@ -249,6 +305,8 @@ Apache::MimeXML
 
 Apache::Mmap
 
+Apache::ModBT
+
 Apache::Module
 
 Apache::ModuleDoc
@@ -289,7 +347,7 @@ Apache::ProxyPass
 
 Apache::ProxyPassThru
 
-Apache::RandomLocation
+Apache::QuickCMS
 
 Apache::RedirectDBI
 
@@ -371,6 +429,8 @@ Apache::Usertrack
 
 Apache::VMonitor
 
+Apache::Voodoo
+
 Apache::WDB
 
 Apache::Watchdog::RunAway
@@ -387,7 +447,7 @@ App::Config
 
 App::Info
 
-App::Manager
+App::Options
 
 AppConfig
 
@@ -399,10 +459,14 @@ AppleII::ProDOS
 
 Archie
 
+Archive::Ar
+
 Archive::Parity
 
 Archive::Tar
 
+Archive::Tar::Stream
+
 Archive::Zip
 
 Argv
@@ -411,6 +475,8 @@ Array::Compare
 
 Array::IntSpan
 
+Array::LineReader
+
 Array::PrintCols
 
 Array::Reform
@@ -461,15 +527,25 @@ Attribute::Types
 
 Audio::CD
 
+Audio::DB
+
 Audio::Ecasound
 
+Audio::FLAC::Decoder
+
+Audio::FLAC::Header
+
+Audio::File
+
 Audio::MPEG
 
+Audio::MikMod
+
 Audio::Mixer
 
-Audio::OSS
+Audio::Moosic
 
-Audio::Play::MPG123
+Audio::OSS
 
 Audio::SoundFile
 
@@ -503,8 +579,14 @@ Authen::TacacsPlus
 
 Authen::Ticket
 
+Authen::Users
+
 Authorizenet
 
+AxKit::XSP::BasicSession
+
+AxKit::XSP::Sendmail
+
 B
 
 B::Deobfuscate
@@ -523,7 +605,7 @@ B::TerseSize
 
 BBDB
 
-BSD::Ipfwgen
+BBDB::Export
 
 BSD::Resource
 
@@ -535,18 +617,32 @@ Be::Attribute
 
 Be::Query
 
+Benchmark::Forking
+
 Benchmark::Timer
 
 BerkeleyDB
 
 BerkeleyDB::Lite
 
+BerkeleyDB::Locks
+
+Biblio::Citation::Parser
+
+Biblio::Document::Parser
+
 Biblio::Thesaurus
 
+Bio::Affymetrix
+
+Bio::GMOD
+
 Bio::Genex
 
 Bio::MAGE
 
+Bio::SAGE
+
 Bit::Vector
 
 BizTalk
@@ -567,14 +663,22 @@ Blatte::Ws
 
 Bleach
 
+Bloom::Filter
+
 BnP
 
 Boulder
 
+Bryar::DataSource::SVNRepos
+
 Bundle::BDFOY
 
 Bundle::Bugzilla
 
+Bundle::Gnome2
+
+Bundle::Knetrix
+
 Bundle::KohaSupport
 
 Bundle::Perl6
@@ -583,10 +687,20 @@ Bundle::SSH
 
 Bundle::Test
 
+Bundle::W3C::Validator
+
+Bundle::ePortal
+
+Business::AU::ACN
+
+Business::AU::TFN
+
 Business::CreditCard
 
 Business::FedEx::DirectConnect
 
+Business::GestPayCrypt
+
 Business::ISBN
 
 Business::ISMN
@@ -597,8 +711,16 @@ Business::NoChex
 
 Business::OnlinePayment
 
+Business::OnlinePayment::E2Payments
+
+Business::OnlinePayment::Moneris
+
 Business::OnlinePayment::WorldPay::Junior
 
+Business::Payroll
+
+Business::Payroll::AU::PAYG
+
 Business::UPC
 
 Business::US_Amort
@@ -611,6 +733,8 @@ C::Include
 
 C::Scan
 
+CAD::Drawing
+
 CDB_File
 
 CDB_File::BiIndex
@@ -619,10 +743,16 @@ CDB_File::BiIndex::Generator
 
 CDDB
 
+CDDB::Fake
+
 CGI::Application
 
+CGI::Application::GDGraph::lines_ap
+
 CGI::Application::PhotoGallery
 
+CGI::Application::Plugin::Stream
+
 CGI::ArgChecker
 
 CGI::Authent
@@ -635,6 +765,8 @@ CGI::CList
 
 CGI::Cache
 
+CGI::DBTables
+
 CGI::Debug
 
 CGI::Deurl
@@ -647,6 +779,8 @@ CGI::Explorer
 
 CGI::FormBuilder
 
+CGI::FormFactory
+
 CGI::FormMagick
 
 CGI::Formalware
@@ -693,6 +827,10 @@ CGI::SecureState
 
 CGI::Session
 
+CGI::Session::DB2
+
+CGI::Session::Encrypted
+
 CGI::SimpleCache
 
 CGI::SpeedyCGI
@@ -703,6 +841,8 @@ CGI::Test
 
 CGI::URI2param
 
+CGI::Untaint::Filenames
+
 CGI::Validate
 
 CGI::WML
@@ -719,12 +859,22 @@ CORBA::IDLtree
 
 CORBA::IOP::IOR
 
+CORBA::XPIDL
+
 CPAN
 
+CPAN::AutoINC
+
+CPAN::Search::Lite::Index
+
 CSS::SAC
 
+Cache::Bounded
+
 Cache::Cache
 
+Cache::FastMemoryCache
+
 Cache::Mmap
 
 Calendar::CSA
@@ -761,18 +911,30 @@ Chart::Pie3d
 
 Chart::Plot
 
+Chart::Plot::Canvas
+
+Chart::Scientific
+
 Chart::XMGR
 
+Chatbot::Alpha
+
 Chatbot::Eliza
 
 Chemistry::Elements
 
+Chemistry::File::PDB
+
 Chipcard::CTAPI
 
 Cisco::Conf
 
 Cisco::IPPhone
 
+Cisco::Reconfig
+
+Clarion
+
 Class::Accessor
 
 Class::ArrayObjects
@@ -781,14 +943,30 @@ Class::BlackHole
 
 Class::Classless
 
+Class::Closure
+
 Class::Contract
 
 Class::DBI
 
+Class::DBI::DB2
+
+Class::DBI::Loader::DB2
+
 Class::DBI::Oracle
 
+Class::DBI::Plugin::CountSearch
+
+Class::DBI::Plugin::Pager
+
+Class::DBI::Template
+
+Class::DBI::Test::TempDB
+
 Class::DBI::mysql
 
+Class::Data::Reloadable
+
 Class::Date
 
 Class::Decorator
@@ -811,14 +989,24 @@ Class::Holon
 
 Class::ISA
 
+Class::Inheritance
+
+Class::IntrospectionMethods
+
 Class::Loader
 
 Class::MakeMethods
 
+Class::MethodFilter
+
 Class::MethodMaker
 
 Class::MethodMapper
 
+Class::Mix
+
+Class::Modular
+
 Class::Multimethods
 
 Class::Mutator
@@ -863,17 +1051,13 @@ Clips
 
 Cmenu
 
-CompBio
-
-CompBio::Simple
+Commands::Guarded
 
 Compress::Bzip2
 
-Compress::LZF
-
 Compress::LZO
 
-Compress::LZV1
+Compress::LZW
 
 Compress::PPMd
 
@@ -889,8 +1073,12 @@ Config::Ini
 
 Config::IniFiles
 
+Config::Magic
+
 Config::Properties
 
+Config::Scoped
+
 ConfigReader::Simple
 
 Conjury::C
@@ -915,8 +1103,12 @@ Convert::Base
 
 Convert::Base32
 
+Convert::Bencode
+
 Convert::BinHex
 
+Convert::Binary::C
+
 Convert::CharMap
 
 Convert::DUDE
@@ -943,14 +1135,14 @@ Convert::Translit
 
 Convert::UU
 
-Convert::UUlib
+Convert::Wiki
 
 Convert::yEnc
 
-Coro
-
 Coy
 
+Crypt::Anubis
+
 Crypt::Blowfish
 
 Crypt::Blowfish_PP
@@ -961,6 +1153,8 @@ Crypt::CBCeasy
 
 Crypt::Caesar
 
+Crypt::Camellia
+
 Crypt::CipherSaber
 
 Crypt::DES
@@ -981,18 +1175,30 @@ Crypt::IDEA
 
 Crypt::Keys
 
+Crypt::Khazad
+
+Crypt::Loki97
+
+Crypt::Misty1
+
 Crypt::NULL
 
+Crypt::Noekeon
+
 Crypt::OTP
 
 Crypt::OpenPGP
 
 Crypt::OpenSSL::BN
 
+Crypt::OpenSSL::PKCS12
+
 Crypt::OpenSSL::RSA
 
 Crypt::OpenSSL::Random
 
+Crypt::OpenSSL::X509
+
 Crypt::PGP5
 
 Crypt::PRSG
@@ -1007,6 +1213,10 @@ Crypt::RC4
 
 Crypt::RSA
 
+Crypt::Rabbit
+
+Crypt::Rainbow
+
 Crypt::RandPasswd
 
 Crypt::Random
@@ -1015,30 +1225,40 @@ Crypt::Rijndael
 
 Crypt::Rijndael_PP
 
+Crypt::SEAL2
+
 Crypt::SKey
 
 Crypt::Schnorr::AuthSign
 
+Crypt::Shark
+
+Crypt::Skipjack
+
 Crypt::SmbHash
 
 Crypt::Solitaire
 
+Crypt::Square
+
 Crypt::TEA
 
 Crypt::TripleDES
 
 Crypt::Twofish
 
-Crypt::Twofish2
-
 Crypt::UnixCrypt
 
+Crypt::UnixCrypt_XS
+
 Curses
 
 Curses::Application
 
 Curses::Forms
 
+Curses::UI::POE
+
 Curses::Widgets
 
 Cz::Cstocs
@@ -1049,12 +1269,18 @@ Cz::Speak
 
 DB2::db
 
+DBA::Backup
+
+DBA::Backup::mysql
+
 DBD::ADO
 
 DBD::ASAny
 
 DBD::Altera
 
+DBD::AnyData
+
 DBD::CSV
 
 DBD::DB2
@@ -1065,6 +1291,8 @@ DBD::Empress
 
 DBD::Excel
 
+DBD::File
+
 DBD::FreeTDS
 
 DBD::Google
@@ -1077,6 +1305,8 @@ DBD::Ingres
 
 DBD::InterBase
 
+DBD::MaxDB
+
 DBD::Multiplex
 
 DBD::ODBC
@@ -1105,6 +1335,8 @@ DBD::Sqlflex
 
 DBD::Sybase
 
+DBD::TSM
+
 DBD::Unify
 
 DBD::XBase
@@ -1125,18 +1357,24 @@ DBIx::Abstract
 
 DBIx::AnyDBD
 
+DBIx::BabelKit
+
 DBIx::Browse
 
 DBIx::CGITables
 
 DBIx::Chart
 
+DBIx::CodeKit
+
 DBIx::Copy
 
 DBIx::DBSchema
 
 DBIx::FetchLoop
 
+DBIx::FileSystem
+
 DBIx::FullTextSearch
 
 DBIx::HTML::ClientDB
@@ -1153,18 +1391,24 @@ DBIx::Lookup::Field
 
 DBIx::MSSQLReporter
 
+DBIx::Objects
+
 DBIx::OracleSequence
 
 DBIx::Password
 
 DBIx::Recordset
 
+DBIx::SQLEngine
+
 DBIx::SchemaView
 
 DBIx::Sequence
 
 DBIx::Simple
 
+DBIx::SimpleQuery
+
 DBIx::SystemCatalog
 
 DBIx::Table
@@ -1173,6 +1417,8 @@ DBIx::Table2Hash
 
 DBIx::TableAdapter
 
+DBIx::TableReferences::MSSQL
+
 DBIx::TextIndex
 
 DBIx::Tree
@@ -1185,6 +1431,8 @@ DBIx::XMLMEssage
 
 DBIx::XML_RDB
 
+DBIx::dbMan
+
 DBIx::glueHTML
 
 DBM::DBass
@@ -1217,6 +1465,8 @@ DFA::Command
 
 DFA::Kleene
 
+DMOZ::ParseRDF
+
 DNS::Config
 
 DNS::Zone
@@ -1225,10 +1475,16 @@ DNS::ZoneParse
 
 DWH_File
 
+Danga::Socket
+
+Data::All
+
 Data::BinStruct
 
 Data::Binder
 
+Data::BitMask
+
 Data::Buffer
 
 Data::Compare
@@ -1237,16 +1493,22 @@ Data::DRef
 
 Data::Denter
 
-Data::Dumper
+Data::Diff
 
 Data::Favorites
 
 Data::Flow
 
+Data::Form::Elements
+
+Data::FormValidator::Upload
+
 Data::HexDump
 
 Data::Hexdumper
 
+Data::ID::Exim
+
 Data::Iterator
 
 Data::JavaScript
@@ -1259,16 +1521,32 @@ Data::MaskPrint
 
 Data::MultiValuedHash
 
+Data::Paginate
+
 Data::Random
 
 Data::Reporter
 
+Data::Search
+
+Data::SecsPack
+
 Data::Serializer
 
 Data::Stash
 
 Data::Tabular::Dumper
 
+Data::TimeSeries
+
+Data::Validate
+
+Data::Validate::Domain
+
+Data::Validate::IP
+
+Data::Variant
+
 Data::Walker
 
 Datascope
@@ -1289,6 +1567,8 @@ Date::Gregorian
 
 Date::Handler
 
+Date::Holidays::AU
+
 Date::ICal
 
 Date::ISO
@@ -1299,18 +1579,34 @@ Date::Language
 
 Date::Manip
 
+Date::Namedays::Simple
+
 Date::Parse
 
 Date::Roman
 
 Date::Simple
 
+Date::Simple::Month
+
 Date::Tolkien::Shire
 
+Date:Jalali
+
 DateTime
 
+DateTime::Calendar::Mayan
+
+DateTime::Event::Cron
+
 DateTime::Event::Easter
 
+DateTime::Format::Builder
+
+DateTime::Format::Pg
+
+DateTime::Format::Strptime
+
 Db::Ctree
 
 Db::DFC
@@ -1365,6 +1661,8 @@ Devel::DebugInit
 
 Devel::DumpStack
 
+Devel::Fail::Make
+
 Devel::FindGlobals
 
 Devel::Hints
@@ -1377,8 +1675,6 @@ Devel::Messenger
 
 Devel::Modlist
 
-Devel::PPPort
-
 Devel::Peek
 
 Devel::RegExp
@@ -1399,18 +1695,30 @@ Devel::TraceLoad
 
 Devel::TraceMethods
 
+Devel::Truth_Table
+
 Device::ISDN::OCLM
 
 Device::ParallelPort
 
 Device::SerialPort
 
+Device::WxM2
+
 Dialog
 
 Digest::BubbleBabble
 
+Digest::CRC
+
+Digest::EMAC
+
+Digest::Elf
+
 Digest::HMAC
 
+Digest::Haval256
+
 Digest::MD2
 
 Digest::MD4
@@ -1419,8 +1727,14 @@ Digest::MD5
 
 Digest::Perl::MD5
 
+Digest::SHA
+
+Digest::SHA::PurePerl
+
 Digest::UserSID
 
+Digest::Whirlpool
+
 Dir::Purge
 
 ERG
@@ -1431,28 +1745,44 @@ Emacs
 
 Emacs::Lisp
 
+Email::AutoReply
+
 Email::Find
 
+Email::Send::SMTP::Auth
+
 Embedix::DB
 
 Embedix::ECD
 
+Encode::Arabic
+
 Encode::HanConvert
 
 Encode::HanDetect
 
 Encode::HanExtra
 
+Encode::Registry
+
+Encode::TECkit
+
+Encode::UTR22
+
 Encode::compat
 
 End
 
+Env::Bash
+
 Env::Modulecmd
 
 Env::Path
 
 Error
 
+Error::TryCatch
+
 Event
 
 Event::Stats
@@ -1467,6 +1797,10 @@ EventServer::Gettimeofday
 
 EventServer::Signal
 
+Excel::Template
+
+Excel::Template::Element::Cell::AutoSize
+
 Exception::Class
 
 Exception::Cxx
@@ -1505,6 +1839,8 @@ Fame
 
 FameHLI
 
+Fax::DataFax
+
 Festival::Client
 
 Festival::Client::Async
@@ -1521,6 +1857,10 @@ File::CacheDir
 
 File::Copy
 
+File::Copy::Link
+
+File::Copy::Recursive
+
 File::CounterFile
 
 File::Data
@@ -1535,9 +1875,11 @@ File::Glob
 
 File::LckPwdF
 
+File::LinearRaid
+
 File::Listing
 
-File::Lock
+File::Locate
 
 File::ManualFlock
 
@@ -1545,8 +1887,12 @@ File::MultiTail
 
 File::NFSLock
 
+File::RandomAccess
+
 File::Remote
 
+File::Remove
+
 File::Repl
 
 File::Rsync
@@ -1557,12 +1903,20 @@ File::Searcher::Interactive
 
 File::Searcher::Similars
 
+File::Signature
+
 File::Slurp
 
 File::Sort
 
 File::Spec
 
+File::Spec::Link
+
+File::Split
+
+File::Stream
+
 File::Sync
 
 File::Tail
@@ -1575,6 +1929,8 @@ File::VirtualPath
 
 File::Which
 
+File::Wildcard
+
 File::chmod
 
 File::lockf
@@ -1585,6 +1941,8 @@ Filesys::DiskFree
 
 Filesys::DiskSpace
 
+Filesys::DiskUsage
+
 Filesys::Ext2
 
 Filesys::SamFS
@@ -1601,6 +1959,8 @@ Filesys::mntent
 
 Filesys::statfs
 
+Filter::Crypto
+
 Filter::NumberLines
 
 Filter::Simple
@@ -1621,30 +1981,60 @@ Filter::sh
 
 Filter::tee
 
+Finance::Amortization
+
+Finance::Bank::AU::StGeorge
+
+Finance::Bank::Commerzbank
+
 Finance::Bank::Commonwealth
 
 Finance::Bank::CreateCard
 
+Finance::Bank::DE::NetBank
+
+Finance::Bank::DE::SpardaBank
+
+Finance::Bank::Wachovia
+
 Finance::NikkeiQuote
 
+Finance::Performance::Calc
+
 Finance::Quote
 
 Finance::QuoteHist
 
+Finance::SE::PPM
+
+Finance::Shares::Chart
+
+Finance::Shares::MySQL
+
 Finance::Streamer
 
 FindBin
 
+FindBin::libs
+
+Flickr::Upload
+
 Font::AFM
 
+Font::FNT
+
 Font::Fret
 
 Font::TFM
 
 Font::TTF
 
+Fortran::Format
+
 Fortran::NameList
 
+FrameMaker::MifTree
+
 FreezeThaw
 
 Frontier::RPC
@@ -1655,12 +2045,22 @@ GD
 
 GD::Barcode
 
+GD::Barcode::Code93
+
 GD::Gauge
 
 GD::Graph
 
 GD::Graph3d
 
+GD::Image::AnimatedGif
+
+GD::Image::Orientation
+
+GD::Image::Thumbnail
+
+GD::SecurityImage
+
 GD::Text
 
 GDS2
@@ -1673,6 +2073,8 @@ GISI::MIFMID
 
 GISI::SHAPE
 
+GMail::Checker
+
 GSM::SMS
 
 GSS
@@ -1683,6 +2085,10 @@ Games::AIBots
 
 Games::Alak
 
+Games::AlphaBeta
+
+Games::Bingo
+
 Games::Cards
 
 Games::Crosswords
@@ -1691,8 +2097,20 @@ Games::Dice
 
 Games::Dissociate
 
+Games::Go::AGATourn
+
+Games::Go::GoPair
+
+Games::Maze
+
 Games::Object
 
+Games::Score
+
+Games::Sequential
+
+Games::Traveller::UWP
+
 Games::WordFind
 
 Games::Worms
@@ -1701,6 +2119,8 @@ Gedcom
 
 Gemstone
 
+Genezzo
+
 Geo::Coordinates::Convert
 
 Geo::Coordinates::UTM
@@ -1715,6 +2135,8 @@ Geo::IP
 
 Geo::METAR
 
+Geo::Projection
+
 Geo::ShapeFile
 
 Geo::WeatherNOAA
@@ -1725,6 +2147,8 @@ Geography::States
 
 Getargs::Long
 
+Getargs::Mixed
+
 Getopt::ArgvFile
 
 Getopt::Attribute
@@ -1739,6 +2163,8 @@ Getopt::Gnu
 
 Getopt::Help
 
+Getopt::Long::File
+
 Getopt::Mixed
 
 Getopt::Regex
@@ -1749,12 +2175,14 @@ Getopt::Tabular
 
 Getopt::Tiny
 
-Gimp
-
 Glade
 
+Glib
+
 Gnome
 
+Gnome2
+
 GnuPG
 
 GnuPG::Interface
@@ -1763,6 +2191,8 @@ Graph
 
 Graph::Kruskal
 
+Graph::Layout::Aesthetic
+
 Graph::Reader
 
 Graph::Reader::XML
@@ -1789,6 +2219,16 @@ Graphics::Plotter
 
 Gtk
 
+Gtk2
+
+Gtk2::Ex::DBI
+
+Gtk2::Ex::FormFactory
+
+Gtk2::MozEmbed
+
+Gtk2::TrayManager
+
 Gtk::Dialog
 
 Guile
@@ -1807,16 +2247,26 @@ HTML::BarGraph
 
 HTML::Base
 
+HTML::Breadcrumbs
+
 HTML::Bricks
 
 HTML::CalendarMonth
 
 HTML::CalendarMonthDB
 
+HTML::Chunks
+
 HTML::Demoroniser
 
+HTML::Diff
+
+HTML::DragAndDrop
+
 HTML::EP
 
+HTML::EasyTable
+
 HTML::EasyTags
 
 HTML::Element
@@ -1843,8 +2293,12 @@ HTML::FormTemplate
 
 HTML::Formatter
 
+HTML::Formulate
+
 HTML::FromANSI
 
+HTML::FromMail
+
 HTML::FromText
 
 HTML::GenToc
@@ -1883,6 +2337,8 @@ HTML::StickyForms
 
 HTML::Stream
 
+HTML::Stripper
+
 HTML::Subtext
 
 HTML::Table
@@ -1897,22 +2353,28 @@ HTML::Tagset
 
 HTML::Template
 
+HTML::Template::Set
+
 HTML::TokeParser
 
+HTML::Tooltip::Javascript
+
 HTML::Validator
 
 HTML::WebMake
 
 HTML::Widgets::DateEntry
 
-HTML::Widgets::Menu
-
 HTML::Widgets::Search
 
 HTTP::BrowserDetect
 
+HTTP::Cache::Transparent
+
 HTTP::Cookies
 
+HTTP::Cookies::Find
+
 HTTP::Cookies::Mozilla
 
 HTTP::Cookies::Omniweb
@@ -1923,12 +2385,16 @@ HTTP::Cookies::iCab
 
 HTTP::DAV
 
+HTTP::DAVServer
+
 HTTP::Daemon
 
 HTTP::Date
 
 HTTP::GHTTP
 
+HTTP::GetImages
+
 HTTP::Headers
 
 HTTP::Message
@@ -1939,6 +2405,8 @@ HTTP::Proxy
 
 HTTP::QuickBase
 
+HTTP::Recorder
+
 HTTP::Request
 
 HTTP::Request::Common
@@ -1993,6 +2461,12 @@ Heap::Elem::StrRev
 
 Heap::Fibonacci
 
+Heap::Simple
+
+Heap::Simple::Perl
+
+Heap::Simple::XS
+
 Hints
 
 Hook::PrePostCall
@@ -2001,6 +2475,8 @@ Hook::Scope
 
 HtDig
 
+HtDig::Htsearch
+
 I18N::Charset
 
 I18N::LangTags
@@ -2013,6 +2489,10 @@ IO::AtomicFile
 
 IO::Default
 
+IO::Event
+
+IO::File::Lockable
+
 IO::Filter
 
 IO::Lines
@@ -2035,6 +2515,8 @@ IO::Stty
 
 IO::Tee
 
+IO::Toolkit
+
 IO::Tty
 
 IO::Wrap
@@ -2047,6 +2529,10 @@ IPC::Cache
 
 IPC::ChildSafe
 
+IPC::DirQueue
+
+IPC::Filter
+
 IPC::LDT
 
 IPC::Locker
@@ -2059,8 +2545,12 @@ IPC::Shareable
 
 IPC::SharedCache
 
+IPC::Shm::Simple
+
 IPC::Signal
 
+IPC::UPDmsg
+
 IPC::XPA
 
 IPChains
@@ -2075,6 +2565,8 @@ Image::DeAnim
 
 Image::Dot
 
+Image::ExifTool
+
 Image::GD::Thumbnail
 
 Image::Grab
@@ -2085,8 +2577,12 @@ Image::Imlib2
 
 Image::Info
 
+Image::Kimdaba
+
 Image::Magick
 
+Image::Magick::BarChart
+
 Image::Maps::Plot::FromLatLong
 
 Image::Maps::Plot::FromPostcode
@@ -2103,8 +2599,12 @@ Image::WMF
 
 Image::WorldMap
 
+Image::Xbm2bmp
+
 Imager
 
+Imager::TimelineDiagram
+
 Include
 
 Ingperl
@@ -2131,16 +2631,24 @@ Inline::Struct
 
 Inline::Tcl
 
+Interface::Param
+
 Ioctl
 
 JUNOS
 
 Java
 
+Java::Build
+
 Java::JVM::Classfile
 
+Java::Swing
+
 JavaScript
 
+Kwiki
+
 LEGO::RCX
 
 LWP
@@ -2153,6 +2661,8 @@ LWP::Parallel
 
 LWP::Protocol
 
+LWP::Protocol::http::SocketUnix
+
 LWP::RobotUA
 
 LWP::Simple
@@ -2165,6 +2675,8 @@ Language::Basic
 
 Language::DATR::DATR2XML
 
+Language::Frink::Eval
+
 Language::Ook
 
 Language::Prolog
@@ -2179,6 +2691,32 @@ Language::VBParser
 
 Language::XSB
 
+Language::Zcode
+
+Lemonldap::Config::Parameters
+
+Lemonldap::Crypto
+
+Lemonldap::Handler
+
+Lemonldap::Handlers::Generic
+
+Lemonldap::Portal
+
+Lemonldap::Portal::Authntsso
+
+Lemonldap::Portal::Cda
+
+Lemonldap::Portal::Sslsso
+
+Lemonldap::Portal::Standard
+
+Lexical::Typeglob
+
+Lingua::AlignmentSet
+
+Lingua::Alphabet::Phonetic
+
 Lingua::Conjunction
 
 Lingua::DetectCharset
@@ -2219,10 +2757,16 @@ Lingua::FR::Numbers
 
 Lingua::FeatureSet
 
+Lingua::GA::Gramadoir
+
 Lingua::GL::Stemmer
 
+Lingua::Han2PinYin
+
 Lingua::Ident
 
+Lingua::Identify
+
 Lingua::Ispell
 
 Lingua::JA::Number
@@ -2233,8 +2777,20 @@ Lingua::Lexicon::IDP
 
 Lingua::PT
 
+Lingua::PT::Conjugate
+
+Lingua::PT::Hyphenate
+
+Lingua::PT::Inflect
+
+Lingua::PT::Nums2Words
+
 Lingua::PT::Stemmer
 
+Lingua::PT::UnConjugate
+
+Lingua::PT::Words2Nums
+
 Lingua::Preferred
 
 Lingua::RU::Antimat
@@ -2245,10 +2801,18 @@ Lingua::Romana::Perligata
 
 Lingua::Stem
 
+Lingua::Stem::Fr
+
+Lingua::Stem::Ru
+
 Lingua::Stem::Snowball::Da
 
 Lingua::TH::Segmentation
 
+Lingua::Tolkien::BURL
+
+Lingua::Treebank
+
 Lingua::ZH::CCDICT
 
 Lingua::ZH::CEDICT
@@ -2281,32 +2845,44 @@ Lingua::Zompist::Verdurian
 
 Linksys::Config
 
-Linux::AIO
-
 Linux::Cpuinfo
 
 Linux::Fuser
 
+Linux::LVM
+
+Linux::MemInfo
+
 Linux::Pid
 
 Linux::Svgalib
 
+List::Comprehensions
+
 List::Intersperse
 
+List::Part
+
 List::Util
 
+List::Util::Superpositions
+
 Locale::Country
 
 Locale::Currency
 
-Locale::Date
+Locale::KeyedText
 
 Locale::Language
 
+Locale::MakePhrase
+
 Locale::Maketext
 
 Locale::Maketext::Fuzzy
 
+Locale::Maketext::Gettext
+
 Locale::Maketext::Lexicon
 
 Locale::Msgcat
@@ -2327,12 +2903,18 @@ LockFile::Scheme
 
 LockFile::Simple
 
+Log::Accounting
+
+Log::Accounting::Sendmail
+
 Log::Agent
 
 Log::Agent::Logger
 
 Log::Agent::Rotate
 
+Log::Check
+
 Log::Delayed
 
 Log::Detect
@@ -2355,8 +2937,12 @@ Log::TraceMessages
 
 Logfile
 
+Lyrics::Fetcher::Google
+
 MARC
 
+MARC::Errorchecks
+
 MARC::Record
 
 MARC::XML
@@ -2379,6 +2965,10 @@ MIME::Lite
 
 MIME::Lite::HTML
 
+MIME::Lite::TT
+
+MIME::Lite::TT::Japanese
+
 MIME::Parser
 
 MIME::QuotedPrint
@@ -2413,6 +3003,10 @@ MP3::Mplib
 
 MP3::Tag
 
+MP4::Info
+
+MPEG::Audio::Frame
+
 MPEG::ID3v2Tag
 
 MPEG::MP3Play
@@ -2457,6 +3051,8 @@ Mac::Gestalt
 
 Mac::Glue
 
+Mac::Growl
+
 Mac::Macbinary
 
 Mac::Memory
@@ -2499,6 +3095,14 @@ Mail::Cap
 
 Mail::CheckUser
 
+Mail::Client::Yahoo
+
+Mail::DSN
+
+Mail::DeliveryStatus::BounceParser
+
+Mail::DomainKeys
+
 Mail::Ezmlm
 
 Mail::Field
@@ -2509,6 +3113,8 @@ Mail::Folder
 
 Mail::Freshmeat
 
+Mail::GPG
+
 Mail::GnuPG
 
 Mail::Header
@@ -2521,6 +3127,8 @@ Mail::ListDetector
 
 Mail::MH
 
+Mail::Maildir
+
 Mail::Mailer
 
 Mail::MboxParser
@@ -2533,6 +3141,10 @@ Mail::Procmailrc
 
 Mail::QmailRemote
 
+Mail::SPF::Query
+
+Mail::SRS
+
 Mail::Send
 
 Mail::Sender
@@ -2543,6 +3155,8 @@ Mail::Sort
 
 Mail::SpamAssassin
 
+Mail::Toaster
+
 Mail::Transport::Dbx
 
 Mail::Util
@@ -2559,7 +3173,9 @@ Mail::Vmailmgr
 
 Make
 
-MasonX::ApacheHandler::WithCallbacks
+Mariachi
+
+MasonX::Maypole
 
 MasonX::Resolver::CVS
 
@@ -2569,6 +3185,8 @@ Math::Amoeba
 
 Math::Approx
 
+Math::Approx::Symbolic
+
 Math::BaseCalc
 
 Math::Bezier
@@ -2577,6 +3195,8 @@ Math::Bezier::Convert
 
 Math::BigInt::BitVect
 
+Math::BigInt::GMP
+
 Math::BigInt::Pari
 
 Math::BigIntFast
@@ -2593,6 +3213,10 @@ Math::Business::BlackScholes
 
 Math::Business::EMA
 
+Math::Business::MACD
+
+Math::Business::SMA
+
 Math::CDF
 
 Math::Calc::Euro
@@ -2611,20 +3235,36 @@ Math::Expr
 
 Math::FFT
 
+Math::Fibonacci::Phi
+
 Math::Fleximal
 
 Math::Fortran
 
+Math::Fractal::Curve
+
 Math::Fractal::DLA
 
 Math::Fraction
 
+Math::FresnalZone
+
+Math::FresnelZone
+
+Math::Function::Roots
+
 Math::Geometry
 
 Math::Geometry::GPC
 
 Math::Geometry::Planar
 
+Math::Geometry::Planar::Offset
+
+Math::Gradient
+
+Math::Group::Thompson
+
 Math::Interpolate
 
 Math::Libm
@@ -2633,10 +3273,14 @@ Math::Logic
 
 Math::Logic::Predicate
 
+Math::MPFR
+
 Math::MagicSquare::Generator
 
 Math::Matrix
 
+Math::Matrix::SVD
+
 Math::MatrixBool
 
 Math::MatrixReal
@@ -2647,6 +3291,10 @@ Math::Nocarry
 
 Math::Pari
 
+Math::Polygon
+
+Math::Polyhedra
+
 Math::Polynomial
 
 Math::Polynomial::Solve
@@ -2657,6 +3305,8 @@ Math::Project3D
 
 Math::Project3D::Plot
 
+Math::Quaternion
+
 Math::RPN
 
 Math::Random
@@ -2673,6 +3323,8 @@ Math::SimpleInterest
 
 Math::Spline
 
+Math::Symbolic
+
 Math::Trig
 
 Math::VecStat
@@ -2683,6 +3335,10 @@ Math::XOR
 
 Math::ematica
 
+MathML::Entities
+
+Maypole::Plugin::Authorization
+
 Memoize::ExpireLRU
 
 Metadata::Base
@@ -2691,7 +3347,7 @@ Metadata::IAFA
 
 Metadata::SOIF
 
-Modem::VBox
+Mobile::UserAgent
 
 Modem::Vgetty
 
@@ -2699,10 +3355,12 @@ Module::Build
 
 Module::Install
 
-Module::InstalledVersion
+Module::Install::Skip
 
 Module::MakeDist
 
+Module::MakefilePL::Parse
+
 Module::Reload
 
 Module::ScanDeps
@@ -2715,12 +3373,20 @@ Mon::SNMP
 
 Msql
 
+Multimedia::SDP
+
+MusicBrainz::Client
+
 MySQL::TableInfo
 
+Myco
+
 Mysql
 
 NEXT
 
+NEXT::init
+
 NNML::Server
 
 Net::ACAP
@@ -2729,14 +3395,26 @@ Net::AIM
 
 Net::AOLIM
 
+Net::Address::Ethernet
+
+Net::BEEP::Lite
+
 Net::BGP
 
 Net::Bind
 
+Net::BitTorrent::LibBTT
+
 Net::CDDBScan
 
+Net::CDP
+
 Net::CIDR
 
+Net::Chat::Daemon
+
+Net::DHCP
+
 Net::DHCP::Watch
 
 Net::DHCPClient
@@ -2745,8 +3423,12 @@ Net::DLookup
 
 Net::DNS
 
+Net::DNS::DynDNS
+
 Net::DNS::SEC
 
+Net::DNS::Zone::Parser
+
 Net::Daemon
 
 Net::Daemon::SSL
@@ -2757,6 +3439,8 @@ Net::EMI::Client
 
 Net::EMI::Common
 
+Net::EPP::Client
+
 Net::FTP
 
 Net::FTPServer
@@ -2789,16 +3473,24 @@ Net::ICQV5CD
 
 Net::ICal
 
+Net::IDN::Encode
+
 Net::IMAP
 
 Net::IMAP::Simple
 
+Net::IP::Match::XS
+
+Net::IPP
+
 Net::Ident
 
 Net::Inet
 
 Net::Interface
 
+Net::Irate
+
 Net::Jabber
 
 Net::LDAP
@@ -2809,22 +3501,34 @@ Net::LMTP
 
 Net::LPR
 
+Net::Mac::Vendor
+
+Net::Milter
+
 Net::NIS
 
 Net::NISPlus
 
 Net::NNTP
 
+Net::NetSend
+
 Net::Netmask
 
 Net::Netrc
 
 Net::OSCAR
 
+Net::P0f
+
 Net::PH
 
 Net::POP3
 
+Net::PSYC
+
+Net::Packet
+
 Net::Pager
 
 Net::ParseWhois
@@ -2841,12 +3545,22 @@ Net::Printer
 
 Net::QMQP
 
+Net::RTSP
+
+Net::RULI
+
+Net::SAP
+
 Net::SCP
 
+Net::SDP
+
 Net::SFTP
 
 Net::SMS
 
+Net::SMS::Clickatell
+
 Net::SMS::Genie
 
 Net::SMS::Web
@@ -2857,6 +3571,8 @@ Net::SNMP
 
 Net::SNMP::Interfaces
 
+Net::SNPP
+
 Net::SSH
 
 Net::SSH::Perl
@@ -2867,6 +3583,8 @@ Net::SSLeay
 
 Net::Server
 
+Net::Subnets
+
 Net::Syslog
 
 Net::TCP
@@ -2883,6 +3601,10 @@ Net::Traceroute6
 
 Net::UDP
 
+Net::Vypress::Chat
+
+Net::WWD
+
 Net::Whois
 
 Net::Whois::IP
@@ -2895,6 +3617,8 @@ Net::Z3950
 
 Net::hostent
 
+Net::iTMS
+
 Net::netent
 
 Net::protoent
@@ -2939,6 +3663,8 @@ Neural
 
 News::Article
 
+News::Article::NoCeM
+
 News::Gateway
 
 News::GnusFilter
@@ -2997,6 +3723,8 @@ NexTrieve::Targz
 
 NexTrieve::UTF8
 
+Nmap::Scanner
+
 No::Dato
 
 No::KontoNr
@@ -3007,10 +3735,18 @@ No::Sort
 
 No::Telenor
 
+Noid
+
+Nokia::File::NFB
+
 Number::Encode
 
 Number::Format
 
+Number::OutlineNumber
+
+Number::Phone::PT
+
 Number::Phone::US
 
 O
@@ -3039,6 +3775,10 @@ ObjStore
 
 Object::Info
 
+Object::Mediator
+
+Object::POOF
+
 Object::Realize::Later
 
 Object::Transaction
@@ -3049,12 +3789,20 @@ OpenCA
 
 OpenGL
 
+OpenOffice::OODoc
+
 Openview::Message
 
 Orac
 
+Oracle::Loader
+
 Oracle::OCI
 
+Oracle::SQLLoader
+
+Oracle::Trace
+
 Oraperl
 
 OurNet
@@ -3067,20 +3815,20 @@ P4::Client
 
 PAR
 
-PApp
-
-PApp::SQL
-
 PCL::Simple
 
 PDA::Pilot
 
 PDF
 
+PDF::API2
+
 PDF::Core
 
 PDF::Create
 
+PDF::FDF::Simple
+
 PDF::Labels
 
 PDF::Parse
@@ -3089,12 +3837,18 @@ PDF::PlainLayout
 
 PDF::Report
 
+PDF::Reuse
+
+PDF::Reuse::Tutorial
+
+PDF::Template
+
 PDL
 
-PDL::Audio
-
 PDL::IO::HDF5
 
+PDL::LAPACK
+
 PDL::Meschach
 
 PDL::NetCDF
@@ -3113,38 +3867,72 @@ PGP::Sign
 
 PGPLOT
 
+PHP
+
 PHP::Include
 
+PHP::MySQL_Session
+
 PHP::Session
 
+POE::API::Hooks
+
+POE::API::Peek
+
 POE::Component::Client::FTP
 
 POE::Component::Client::HTTP
 
 POE::Component::Client::Ping
 
+POE::Component::Client::TCPMulti
+
 POE::Component::Client::UserAgent
 
+POE::Component::ControlPort
+
+POE::Component::Daemon::Win32
+
+POE::Component::DebugShell
+
+POE::Component::Enc::Flac
+
+POE::Component::Enc::Ogg
+
+POE::Component::IRC
+
 POE::Component::IRC::Onjoin
 
-POE::Component::IRC::SearchEngine
-
 POE::Component::MPG123
 
+POE::Component::OSCAR
+
 POE::Component::Pcap
 
+POE::Component::Pool::Thread
+
+POE::Component::Proxy::TCP
+
 POE::Component::RSS
 
 POE::Component::Server::HTTP
 
+POE::Component::Server::Syslog
+
 POE::Component::SubWrapper
 
 POE::Component::UserBase
 
+POE::Exceptions
+
 POE::Kernel
 
+POE::Loop::Glib
+
 POE::Session
 
+POE::Session::Cascading
+
 POE::Session::GladeXML
 
 PPM
@@ -3155,16 +3943,30 @@ PPresenter
 
 PV
 
+Palm::Magellan::NavCompanion
+
+Palm::Memo32
+
+Palm::SMS
+
+Paper::Specs
+
 Parallel::ForkManager
 
 Parallel::Pvm
 
+Params::Validate
+
 Parse::FixedLength
 
 Parse::Lex
 
 Parse::Lexer
 
+Parse::Nessus::ENX
+
+Parse::Nessus::NBE
+
 Parse::PlainConfig
 
 Parse::RecDescent
@@ -3189,6 +3991,8 @@ Perf::ARM
 
 Perl
 
+Perl6::Classes
+
 Perl6::Interpolators
 
 Perl6::Parameters
@@ -3199,6 +4003,8 @@ PerlIO
 
 PerlIO::gzip
 
+PerlIO::locale
+
 PerlMenu
 
 PerlPoint::Package
@@ -3225,10 +4031,20 @@ Pg
 
 Physics::Particles
 
+Physics::Solar::VSO
+
+Physics::Springs
+
+Physics::Springs::Friction
+
 Physics::Unit
 
 PixDraw
 
+Plugin::Installer
+
+Plugin::Language::DML
+
 Pod::Checker
 
 Pod::DocBook
@@ -3289,8 +4105,6 @@ PostScript::Graph::Key
 
 PostScript::Graph::Paper
 
-PostScript::Graph::Stock
-
 PostScript::Graph::Style
 
 PostScript::Graph::XY
@@ -3319,6 +4133,8 @@ Proc::ExitStatus
 
 Proc::Forkfunc
 
+Proc::Forking
+
 Proc::ParallelLoop
 
 Proc::ProcessTable
@@ -3339,6 +4155,8 @@ Proc::SyncExec
 
 Proc::times
 
+Project::Gantt
+
 Protect
 
 Proxy::Tk
@@ -3361,6 +4179,8 @@ Python::Err
 
 Python::Object
 
+QWizard
+
 Qt
 
 Quantum::Entanglement
@@ -3369,6 +4189,8 @@ Quantum::Superpositions
 
 Quantum::Usrn
 
+Quiz::Question
+
 Quota
 
 R3
@@ -3389,6 +4211,14 @@ RDF::Redland
 
 RDF::Service
 
+RFID::Alien
+
+RFID::Base
+
+RFID::EPC
+
+RFID::Matrics
+
 RPC::ONC
 
 RPC::PlClient
@@ -3407,24 +4237,32 @@ RPM::Headers
 
 RT
 
+RTF::Generator
+
 RTF::Parser
 
-RTF::Reader
-
 RTF::Tokenizer
 
+RTSP::Lite
+
 Rcs
 
 Readonly
 
-Ref
+Regexp::Assemble
 
 Regexp::Common
 
+Regexp::Extended
+
 Regexp::Func
 
+Regexp::Genex
+
 Regexp::Shellish
 
+Regexp::Tr
+
 Relations
 
 ReleaseAction
@@ -3453,6 +4291,8 @@ Router::LG
 
 SAP::Rfc
 
+SCUBA::Table::NoDeco
+
 SGI::FAM
 
 SGI::FM
@@ -3463,6 +4303,8 @@ SGML::Entity
 
 SGML::Parser
 
+SGML::Parser::OpenSP
+
 SGML::SPGrove
 
 SGMLS
@@ -3483,12 +4325,18 @@ SNMP::Util
 
 SOAP::Clean
 
+SOAP::WSDL
+
 SOOP
 
+SQL::Abstract::Limit
+
 SQL::Builder
 
 SQL::Generator
 
+SQL::Routine
+
 SQL::Schema
 
 SQL::Snippet
@@ -3505,6 +4353,12 @@ SVG::Element
 
 SVG::Graph
 
+SVG::Manual
+
+SVG::Template
+
+SVG::Template::Graph
+
 SVG::XML
 
 SWIFT::Factory::ApplicationHeader
@@ -3533,6 +4387,8 @@ SWIFT::Factory::Tag::Tag30V
 
 Safe::Hole
 
+Scalar::Footnote
+
 Scalar::Properties
 
 Scalar::Util
@@ -3547,18 +4403,28 @@ Schedule::Load
 
 Schedule::Match
 
+Script::Toolbox
+
 Search::Binary
 
+Search::ContextGraph
+
 Search::FreeText
 
 Search::InvertedIndex
 
+Search::VectorSpace
+
+Search::Xapian
+
 Sendmail::AccessDB
 
 Sendmail::Milter
 
 Server::Server::EventDriven
 
+Set::Array
+
 Set::Bag
 
 Set::CheckList
@@ -3567,6 +4433,8 @@ Set::Crontab
 
 Set::CrossProduct
 
+Set::Hash
+
 Set::Infinite
 
 Set::IntRange
@@ -3579,8 +4447,14 @@ Set::Object
 
 Set::Scalar
 
+Set::String
+
 Set::Window
 
+Shell::POSIX::Select
+
+Shell::Parser
+
 Shell::Source
 
 ShellScript::Env
@@ -3609,6 +4483,12 @@ Solaris::ACL
 
 Solaris::Contents
 
+Solaris::Disk::Mnttab
+
+Solaris::Disk::SVM
+
+Solaris::Disk::VTOC
+
 Solaris::InstallDB
 
 Solaris::Kstat
@@ -3669,8 +4549,6 @@ Statistics::ROC
 
 Statistics::TTest
 
-Strict::Prototype
-
 String::Approx
 
 String::BitCount
@@ -3693,26 +4571,36 @@ String::Random
 
 String::RexxParse
 
+String::Ruby
+
 String::Scanf
 
 String::ShellQuote
 
-String::Similarity
-
 String::Strip
 
+Sub::Assert
+
 Sub::Curry
 
+Sub::DeferredPartial
+
 Sub::Quotelike
 
+Sub::Recursive
+
 Sub::Regex
 
 Sun::Solaris::Exacct
 
+Sun::Solaris::Privilege
+
 Sun::Solaris::Project
 
 Sun::Solaris::Task
 
+Sun::Solaris::Ucred
+
 Sx
 
 Sybase::BCP
@@ -3731,18 +4619,36 @@ Symbol::Approx::Sub
 
 Symbol::Table
 
+Synergy
+
+Syntax::Highlight::HTML
+
 Syntax::Highlight::Perl
 
+Syntax::Highlight::Shell
+
 Sys::AlarmCall
 
 Sys::CPU
 
+Sys::Filesystem::Dummy
+
+Sys::Filesystem::Linux
+
+Sys::Filesystem::Solaris
+
+Sys::Filesystem::Unix
+
 Sys::Hostname::Long
 
 Sys::Lastlog
 
+Sys::PortIO
+
 Sys::Sysconf
 
+Sys::Uptime
+
 Sys::Utmp
 
 SyslogScan::SendmailLine
@@ -3761,6 +4667,8 @@ TFTP
 
 Taint
 
+Taint::Runtime
+
 Tangram
 
 Tasks
@@ -3769,18 +4677,32 @@ Tcl
 
 Tcl::Tk
 
+TeX::Convert::Image
+
 TeX::DVI
 
 TeX::Hyphen
 
+Telephony::CountryDialingCodes
+
 Telephony::Phonedev
 
 Template
 
+Template::Plugin::Config::General
+
+Template::Plugin::Data::HTMLDumper
+
+Template::Plugin::SSI
+
 Template::Plugin::StickyQuery
 
+Template::Plugin::Translit::RU
+
 Term::ANSIScreen
 
+Term::Activity
+
 Term::EditLine
 
 Term::Gnuplot
@@ -3809,6 +4731,8 @@ Term::Size
 
 Term::Size::Heuristic
 
+Term::Slang
+
 Term::TUI
 
 Term::Twiddle
@@ -3831,22 +4755,42 @@ Test::FIT
 
 Test::File
 
+Test::File::Find::Rule
+
 Test::ISBN
 
+Test::LectroTest
+
 Test::Litmus
 
-Test::Mail
-
 Test::Manifest
 
+Test::MockClass
+
+Test::MockDBI
+
+Test::MockRandom
+
 Test::More
 
+Test::MultiFork
+
+Test::Number::Delta
+
+Test::Numeric
+
 Test::Pod
 
+Test::Portability::Files
+
 Test::Reporter
 
+Test::Signature
+
 Test::Simple
 
+Test::TempDatabase
+
 Test::URI
 
 Test::Unit
@@ -3855,12 +4799,16 @@ Test::Version
 
 Text::ASCIITable
 
+Text::Affixes
+
 Text::Balanced
 
 Text::Banner
 
 Text::BarGraph
 
+Text::Beautify
+
 Text::Bib
 
 Text::BibTeX
@@ -3869,6 +4817,16 @@ Text::CSV
 
 Text::CSV_XS
 
+Text::Capitalize
+
+Text::Cipher
+
+Text::Contraction
+
+Text::Conversation
+
+Text::Convert::ToImage
+
 Text::DelimMatch
 
 Text::DoubleMetaphone
@@ -3895,42 +4853,68 @@ Text::Iconv
 
 Text::Macros
 
+Text::Merge
+
 Text::MetaText
 
 Text::Metaphone
 
 Text::MicroMason
 
+Text::Netstring
+
+Text::Ngram
+
 Text::Orientation
 
 Text::Parser
 
+Text::Query
+
 Text::Refer
 
 Text::Scan
 
 Text::ScriptTemplate
 
+Text::Shift
+
+Text::Similarity
+
 Text::SimpleTemplate
 
+Text::SpellChecker
+
 Text::Stem
 
 Text::Substitute
 
+Text::Table
+
+Text::TagTemplate
+
 Text::Templar
 
 Text::Template
 
+Text::Tokenizer
+
 Text::TreeFile
 
 Text::Trie
 
 Text::Vpp
 
+Text::Wigwam
+
 Text::Wrap::Hyphenate
 
 Text::iPerl
 
+Text::vCard
+
+Text::vFile
+
 Text::xSV
 
 Thesaurus
@@ -3941,10 +4925,16 @@ Thread::Pool
 
 Thread::RWLock
 
+TiVo::HME
+
 Tibco::Rv
 
 Tie::AliasHash
 
+Tie::Array::CustomStorage
+
+Tie::Assert
+
 Tie::CPHash
 
 Tie::Cache
@@ -3955,6 +4945,10 @@ Tie::CharArray
 
 Tie::Concurrent
 
+Tie::Constrained
+
+Tie::Cvs
+
 Tie::Cycle
 
 Tie::DBI
@@ -3971,12 +4965,18 @@ Tie::DxHash
 
 Tie::File
 
+Tie::File::AsHash
+
 Tie::FileLRUCache
 
 Tie::GHash
 
 Tie::Handle
 
+Tie::Hash::CustomStorage
+
+Tie::Hash::MultiValue
+
 Tie::Hash::Regex
 
 Tie::Hash::Stack
@@ -4021,6 +5021,8 @@ Tie::SentientHash
 
 Tie::ShadowHash
 
+Tie::Simple
+
 Tie::SortHash
 
 Tie::StrictHash
@@ -4037,6 +5039,8 @@ Tie::WarnGlobal
 
 Tie::Watch
 
+Tie::iCal
+
 Time::Avail
 
 Time::CTime
@@ -4045,6 +5049,8 @@ Time::DaysInMonth
 
 Time::Duration::sv
 
+Time::Format
+
 Time::HiRes
 
 Time::JulianDateTime
@@ -4057,6 +5063,8 @@ Time::ParseDate
 
 Time::Period
 
+Time::Piece::DB2
+
 Time::Piece::MySQL
 
 Time::Seconds
@@ -4067,6 +5075,8 @@ Time::TAI64
 
 Time::Timezone
 
+Time::UTC
+
 Time::Unix
 
 Time::Warp
@@ -4075,12 +5085,16 @@ Time::Zone
 
 Tk
 
+Tk::ApplicationNest
+
 Tk::Autoscroll
 
 Tk::Axis
 
 Tk::Calculator::RPN::HP
 
+Tk::Carp
+
 Tk::CheckBox
 
 Tk::ChildNotification
@@ -4101,6 +5115,8 @@ Tk::Copy::Mac
 
 Tk::CursorControl
 
+Tk::DBIx
+
 Tk::Date
 
 Tk::DateEntry
@@ -4109,6 +5125,12 @@ Tk::DatePick
 
 Tk::Dial
 
+Tk::DirSelect
+
+Tk::DynaTabFrame
+
+Tk::ErrorDump
+
 Tk::ExecuteCommand
 
 Tk::FcyEntry
@@ -4137,12 +5159,16 @@ Tk::IPEntry
 
 Tk::IconCanvas
 
+Tk::ImageButton
+
 Tk::JComboBox
 
 Tk::JPEG
 
 Tk::LCD
 
+Tk::LineNumberText
+
 Tk::LockDisplay
 
 Tk::MListbox
@@ -4167,6 +5193,8 @@ Tk::ObjScanner
 
 Tk::Olwm
 
+Tk::OutlookBar
+
 Tk::PNG
 
 Tk::Pane
@@ -4177,18 +5205,30 @@ Tk::Pgplot
 
 Tk::PhotoRotate
 
+Tk::Playlist
+
 Tk::Pod
 
 Tk::ProgressBar
 
 Tk::ProgressBar::Mac
 
+Tk::ReportBox
+
 Tk::RotCanvas
 
+Tk::Separator
+
+Tk::SignOnDialog
+
+Tk::SlideSwitch
+
 Tk::Splashscreen
 
 Tk::SplitFrame
 
+Tk::Statusbar
+
 Tk::Stderr
 
 Tk::TFrame
@@ -4223,6 +5263,8 @@ Tk::Workspace
 
 Tk::XMLViewer
 
+Tk::Zinc
+
 Tk::autobind
 
 ToolTalk
@@ -4231,7 +5273,9 @@ Tree::DAG_Node
 
 Tree::Fat
 
-Tree::M
+Tree::List2Tree
+
+Tree::Menu
 
 Tree::Nary
 
@@ -4245,6 +5289,8 @@ UDDI
 
 UML::Sequence
 
+UML::State
+
 URI::Attr
 
 URI::Bookmark
@@ -4255,6 +5301,8 @@ URI::Escape
 
 URI::Find
 
+URI::OpenURL
+
 URI::Sequin
 
 URI::URL
@@ -4273,6 +5321,8 @@ Unicode::MapUTF8
 
 Unicode::String
 
+Unicode::UTF8simple
+
 Unix::ConfigFile
 
 Unix::Login
@@ -4295,6 +5345,8 @@ User::pwent
 
 VCS
 
+VCS::CMSynergy
+
 VCS::StarTeam
 
 VMS::Device
@@ -4345,12 +5397,20 @@ Verilog::Pli
 
 Verilog::SigParser
 
-Video::Capture::V4l
+Visio
+
+Voicent
+
+Vonage::Click2Call
+
+W3C::LinkChecker
 
 WAIT
 
 WDDX
 
+WIN32::MSI::SummaryInfo
+
 WING
 
 WML::Card
@@ -4359,14 +5419,34 @@ WML::Deck
 
 WWW::BBSWatch
 
+WWW::Blog::Identify
+
 WWW::Cache::Google
 
+WWW::Dilbert
+
+WWW::Extractor
+
+WWW::ImageSpool
+
+WWW::Lunarstorm
+
+WWW::Lyrics
+
 WWW::Mail::Hotmail
 
+WWW::Mechanize
+
+WWW::Patent::Page
+
+WWW::Pipeline
+
 WWW::Robot
 
 WWW::RobotRules
 
+WWW::Scraper::ISBN
+
 WWW::Search
 
 WWW::Search::AlltheWeb
@@ -4395,6 +5475,14 @@ WWW::SherlockSearch
 
 WWW::ShopBot
 
+WWW::Statistics
+
+WWW::URLToys
+
+WWW::Webjay
+
+WWW::Yahoo::DrivingDirections
+
 Wais
 
 Watchdog::HTTPService
@@ -4403,18 +5491,28 @@ Watchdog::MysqlService
 
 Watchdog::Service
 
+Weather::NOAA::GFS
+
 WebCache::Digest
 
 WebFS::FileCopy
 
+WebService::BabelFish
+
 WebService::FreeDB
 
+WebService::GoogleMaps
+
+WebService::Mappoint
+
 WebSphere::Payment
 
 Whitespace
 
 Widget::FixedWidthFont::Input
 
+Wily
+
 Win32::ADO
 
 Win32::API
@@ -4443,8 +5541,16 @@ Win32::EventLog
 
 Win32::EventLog::Carp
 
+Win32::Exchange::Mailbox
+
+Win32::Exchange::SMTP::Security
+
 Win32::FUtils
 
+Win32::FetchCommand
+
+Win32::File::VersionInfo
+
 Win32::FileOp
 
 Win32::FileType
@@ -4453,10 +5559,18 @@ Win32::GD
 
 Win32::GUI
 
+Win32::GUI::Carp
+
+Win32::GUI::HyperLink
+
+Win32::GUID
+
 Win32::GuiTest
 
 Win32::Guidgen
 
+Win32::IIS:SMTP
+
 Win32::IPC
 
 Win32::Internet
@@ -4479,16 +5593,28 @@ Win32::OLE
 
 Win32::OLE::OPC
 
+Win32::Perfmon
+
 Win32::Pipe
 
 Win32::Process
 
 Win32::Process::Info
 
+Win32::Process::Perf
+
 Win32::RASE
 
 Win32::Registry
 
+Win32::RemoteTOD
+
+Win32::Resources
+
+Win32::SAPI5
+
+Win32::SearchPath
+
 Win32::Semaphore
 
 Win32::SerialPort
@@ -4503,14 +5629,22 @@ Win32::SoundRec
 
 Win32::SystemInfo
 
+Win32::UTCFileTime
+
 Win32::WinError
 
 Win32API::CommPort
 
+Win32API::File::Time
+
 Win32API::MIDI
 
 Win32API::Registry
 
+WordNet::SenseRelate
+
+WordNet::Similarity
+
 Workflow
 
 Wx
@@ -4519,6 +5653,8 @@ Wx::ActiveX
 
 X11::Auth
 
+X11::FreeDesktop::DesktopEntry
+
 X11::Fvwm
 
 X11::Keysyms
@@ -4551,10 +5687,14 @@ X500::DN::Parser
 
 X500::RDN
 
+X::Osd
+
 XBase
 
 XML
 
+XML::ASCX12
+
 XML::AutoWriter
 
 XML::CSV
@@ -4571,6 +5711,8 @@ XML::Comma
 
 XML::DOM
 
+XML::DT
+
 XML::Directory
 
 XML::Doctype
@@ -4605,12 +5747,20 @@ XML::Grove
 
 XML::Handler::Composer
 
+XML::Handler::EasyTree::Generator
+
 XML::Handler::PrintEvents
 
+XML::Handler::Trees
+
+XML::LibXML
+
 XML::Mini
 
 XML::NamespaceSupport
 
+XML::OPML
+
 XML::PPD
 
 XML::PYX
@@ -4645,6 +5795,8 @@ XML::Twig
 
 XML::UM
 
+XML::Validator::Schema
+
 XML::Writer
 
 XML::Writer::String
@@ -4675,8 +5827,14 @@ Xmms::Remote
 
 YAML
 
+Yahoo::Search
+
 dTemplate
 
+define
+
+ePortal
+
 ex::caution
 
 ex::constant::vars
@@ -4687,13 +5845,26 @@ ex::interface
 
 ex::override
 
-namespace
+fields::aliased
 
+iCal::Parser
+
+iCal::Parser::HTML
+
+iCal::Parser::SAX
+
+namespace
 
 =head1 CHANGES
 
 =over 4
 
+=item 0.03
+
+Update to current module list
+
+Should this be Bundle::Acme::Everything?  Doesn't make much more sense, does it?
+
 =item 0.02
 
 Update to current module list
